// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.0

Rectangle {
    id: rectSetup
    anchors.fill: parent
    visible: false

    property bool newTraining: false
    property int currentTraining: -1

    function addTraining(training_seconds,rest_seconds,laps)
    {
        addTrainingScreen.addTraining(training_seconds,rest_seconds,laps)
    }

    function clearList()
    {
        addTrainingScreen.clearList();
    }

    state: "trainings"

    states:[
        State{
            name: "trainings"
            PropertyChanges{target: setupHeader; source: "qrc:/images/setup_training.png"}
            PropertyChanges{target: optionsButton; visible: true}
            PropertyChanges{target: trainingButton; visible: false}
            PropertyChanges{target: addTrainingScreen; visible: true}
            PropertyChanges{target: buttonSave; visible: false}
            PropertyChanges{target: buttonRemove; visible: false}
            PropertyChanges{target: optionsScreen; visible: false}
            //PropertyChanges{target: mouseSetupTraining; enabled: false}
            //PropertyChanges{target: mouseSetupOptions; enabled: true}
        },
        State{
            name: "options"
            PropertyChanges{target: setupHeader; source: "qrc:/images/setup_options.png"}
            PropertyChanges{target: optionsButton; visible: false}
            PropertyChanges{target: trainingButton; visible: true}
            PropertyChanges{target: addTrainingScreen; visible: false}
            PropertyChanges{target: buttonSave; visible: false}
            PropertyChanges{target: buttonRemove; visible: false}
            PropertyChanges{target: optionsScreen; visible: true}
            //PropertyChanges{target: rectSetup; newTraining: false}
            //PropertyChanges{target: mouseSetupTraining; enabled: true}
            //PropertyChanges{target: mouseSetupOptions; enabled: false}
        },
        State{
            name: "editTraining"
            PropertyChanges{target: setupHeader; source: "qrc:/images/setup_training.png"}
            PropertyChanges{target: optionsButton; visible: true}
            PropertyChanges{target: trainingButton; visible: false}
            PropertyChanges{target: addTrainingScreen; visible: false}
            PropertyChanges{target: editTrainingScreen; visible: true}
            PropertyChanges{target: buttonSave; visible: true}
            PropertyChanges{target: buttonRemove; visible: { if (newTraining) return false; else return true}}
            PropertyChanges{target: optionsScreen; visible: false}
            //PropertyChanges{target: mouseSetupOptions; enabled: false}
        }
    ]

    Image {
        id: mainBackgroud
        source: "qrc:/images/background.png"
        anchors.top:parent.top
        anchors.left: parent.left
        anchors.topMargin: 35
    }

    Image{
        id: setupBack
        source: "qrc:/images/setup_background_long.png"
        anchors.left: parent.left
        anchors.leftMargin: (parent.width - setupBack.width) / 2
        anchors.top: parent.top
        anchors.topMargin: 190
        TrainingAddScreen{
            id: addTrainingScreen
            anchors.fill: parent
        }

        OptionsScreen{
            id: optionsScreen
            anchors.fill: parent
        }

        TrainingEdit{
            id: editTrainingScreen
            anchors.fill: parent
            visible: false
            //train_seconds: train_sec
            //rest_seconds: rest_sec

        }
    }

    Image{
        id: setupHeader
        source: "qrc:/images/setup_training.png"
        anchors.left: setupBack.left
        anchors.bottom: setupBack.top
        anchors.topMargin: 5
        Image{

            Rectangle{
                id: maskTraining
                anchors.right: parent.right
                anchors.top: parent.top
                anchors.topMargin: 3
                height: parent.height - 3
                width: parent.width - 5
                color: "white"
                z: parent.z -1
            }

            id: trainingButton
            visible: false
            anchors.left: parent.left
            anchors.top: parent.top
            source: "qrc:/images/setup_training_button.png"
            MouseArea{
                id: mouseSetupTraining
                anchors.fill: parent
                //enabled: false
                onPressed: parent.opacity = 0.7
                onReleased: parent.opacity = 1
                onClicked: {
                    rectSetup.state = "trainings"
                    if (vibration) shortFeedback.start()
                    console.log("training setup clicked")
                }
            }
        }

        Image{
            Rectangle{
                id: maskOptions
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.topMargin: 3
                height: parent.height - 3
                width: parent.width - 5
                color: "white"
                z: parent.z -1
            }

            id: optionsButton
            anchors.right: parent.right
            anchors.top: parent.top
            source: "qrc:/images/setup_options_button.png"
            MouseArea{
                id: mouseSetupOptions
                anchors.fill: parent
                onPressed: parent.opacity = 0.7
                onReleased: parent.opacity = 1
                onClicked: {
                    rectSetup.state = "options"
                    if (vibration) shortFeedback.start()
                    console.log("training setup clicked")
                }
            }
        }
    }

    Text {
        id: setupOptionsText
        text: optionsString
        color: "white"
        anchors.top: setupHeader.top
        anchors.topMargin: 10
        anchors.left: setupHeader.left
        anchors.leftMargin: setupHeader.width / 2
        width: setupHeader.width / 2
        //font.bold: true
        font.pixelSize: 30
        z:optionsButton.z +1
        horizontalAlignment: Text.AlignHCenter
    }

    Text {
        id: setupTrainingText
        text: trainingString
        color: "white"
        anchors.top: setupHeader.top
        anchors.topMargin: 10
        anchors.left: setupHeader.left
        width: setupHeader.width / 2
        //font.bold: true
        font.pixelSize: 30
        z:optionsButton.z +1
        horizontalAlignment: Text.AlignHCenter
    }

    Image{
        id: buttonBack
        source: "qrc:/images/button.png"
        anchors.left: parent.left
        anchors.leftMargin: (parent.width/2 - width - 15)
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 35
        MouseArea{
            id: mouseBack
            anchors.fill: parent
            onPressed: parent.opacity = 0.7
            onReleased: parent.opacity = 1
            onClicked: {
                if (vibration) shortFeedback.start()
                optionsScreen.hideSelect()
                if (rectSetup.state === "editTraining") rectSetup.state = "trainings"
                else showMain()
            }
        }
        Text{
            id: textBack
            text: backString
            anchors.centerIn: parent
            font.pixelSize: 25
            font.bold: true
            font.family: "Arial"
            color: "black"
        }
    }

    Image{
        id: buttonSave
        source: "qrc:/images/button.png"
        anchors.left: parent.left
        anchors.leftMargin: (parent.width/2 + 15)
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 125
        MouseArea{
            id: mouseSave
            anchors.fill: parent
            onPressed: parent.opacity = 0.7
            onReleased: parent.opacity = 1
            onClicked: {
                if (vibration) shortFeedback.start()

                if (newTraining)
                {
                    trainingRemoved = false
                    addTrainingScreen.addTraining(editTrainingScreen.train_seconds,editTrainingScreen.rest_seconds,editTrainingScreen.lapsCountNew)
                }
                else
                {
                    trainingRemoved = true
                    addTrainingScreen.updateTraining(editTrainingScreen.train_seconds,editTrainingScreen.rest_seconds,editTrainingScreen.lapsCountNew,currentTraining)
                }
                rectSetup.state = "trainings"
                //showMain()
            }
        }
        Text{
            id: textSave
            text: saveString
            anchors.centerIn: parent
            font.pixelSize: 25
            font.bold: true
            font.family: "Arial"
            color: "black"
        }
    }

    Image{
        id: buttonRemove
        source: "qrc:/images/button.png"
        anchors.left: parent.left
        anchors.leftMargin: (parent.width/2 - width - 15)
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 125
        MouseArea{
            id: mouseRemove
            anchors.fill: parent
            onPressed: parent.opacity = 0.7
            onReleased: parent.opacity = 1
            onClicked: {
                if (vibration) shortFeedback.start()
                trainingRemoved = true
                if (actualIndex == editIndex) {
                    actualIndex = 0
                }
                addTrainingScreen.removeTraining(currentTraining)
                rectSetup.state = "trainings"
                //showMain()
            }
        }
        Text{
            id: textRemove
            text: removeString
            anchors.centerIn: parent
            font.pixelSize: 25
            font.bold: true
            font.family: "Arial"
            color: "black"
        }
    }

    Image{
        id: buttonAbout
        source: "qrc:/images/button.png"
        anchors.left: parent.left
        anchors.leftMargin: (parent.width/2 + 15)
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 35
        MouseArea{
            id: mouseAbout
            anchors.fill: parent
            onPressed: parent.opacity = 0.7
            onReleased: parent.opacity = 1
            onClicked: {
                aboutScreen.visible = true
                console.log("About clicked")
            }
        }
        Text{
            id: textAbout
            text: aboutString
            anchors.centerIn: parent
            font.pixelSize: 25
            font.bold: true
            font.family: "Arial"
            color: "black"
        }
    }

    AboutScreen
    {
        id: aboutScreen
        anchors.fill: parent
    }

}
