import QtQuick 1.0

Rectangle {
    id: container
    color: "transparent"
    clip: true;

    function clear()
    {
        trainingModel.clear();
    }

    function saveTrainingsList()
    {
        var str = ""

        for (var i=0;i<listView.count;i++)
        {
            listView.currentIndex = i
            str = str + listView.currentItem.getTraining()
            str = str + ";" + listView.currentItem.getRest()
            str = str + ";" + listView.currentItem.getLaps()
            if (i !== listView.count - 1) str = str + ";"
        }
        console.log(str)
        saveTrainings(str)
        training_list = str;
        refreshList(true)
        listView.currentIndex = -1;
    }

    function addTraining(training_seconds,rest_seconds,laps)
    {
        trainingModel.append({
                 "training_sec": training_seconds,
                 "rest_sec": rest_seconds,
                 "laps": laps
            })
        listView.currentIndex = -1
        saveTrainingsList()
    }

    function updateTraining(training_seconds,rest_seconds,laps,ind)
    {
        trainingModel.setProperty(ind,"training_sec",training_seconds)
        trainingModel.setProperty(ind,"rest_sec",rest_seconds)
        trainingModel.setProperty(ind,"laps",laps)
    }

    function isEmpty()
    {
        return !listView.count
    }

    function removeTraining(ind)
    {
        trainingModel.remove(ind)
        saveTrainingsList()
    }

    // The model:
    ListModel {
        id: trainingModel
        /*ListElement {
            training_sec: 350
            rest_sec: 100
            laps: 9
        }
        ListElement {
            training_sec: 680
            rest_sec: 200
            laps: 15
        }
        ListElement {
            training_sec: 50
            rest_sec: 300
            laps: 39
        }
        ListElement {
            training_sec: 50
            rest_sec: 400
            laps: 10
        }*/
    }

    // The delegate for each fruit in the model:
    Component {
        id: listDelegate
        Item {
            id: delegateItem
            width: listView.width; height: 60

            function getTraining()
            {
                return training_sec
            }

            function getRest()
            {
                return rest_sec
            }

            function getLaps()
            {
                return laps
            }

            MouseArea{
                id: itemClick
                anchors.fill: parent

                onClicked: {
                    //listView.currentIndex = index
                    if (vibration) shortFeedback.start()
                    editTrainingScreen.rest_seconds = rest_sec
                    editTrainingScreen.train_seconds = training_sec
                    editTrainingScreen.lapsCountNew = laps
                    rectSetup.newTraining = false
                    rectSetup.currentTraining = index
                    rectSetup.state = "editTraining"
                    editIndex = index
                    console.log("training clicked");
                }

                onPressed: {
                    listView.currentIndex = index
                }
                onCanceled: listView.currentIndex = -1
                onReleased: listView.currentIndex = -1
            }
            //Column{
            Item{
                id: icon
                width: trainingListBorder.width
                anchors.centerIn: parent
                Image{
                    id: trainingListBorder
                    anchors.centerIn: parent

                    source: "qrc:/images/training_list_border.png"
                }

                Text{
                    id: trainingMinsText
                    text: {
                        var mins = (training_sec - (training_sec % 60)) / 60
                        if (mins.toString().length < 2) {
                            return "0" + mins
                        }
                        else return mins
                    }

                    color: "white"
                    width: 40
                    height: icon.height
                    anchors.top: icon.top
                    anchors.topMargin: -15
                    anchors.left: icon.left
                    anchors.leftMargin: 75
                    font.pixelSize: 25
                    font.bold: true
                    horizontalAlignment: Text.AlignHCenter
                }

                Text{
                    id: trainingTextSeparator
                    text: ":"
                    color: "white"
                    width: 5
                    height: icon.height
                    anchors.top: icon.top
                    anchors.topMargin: -15
                    anchors.left: trainingMinsText.right
                    font.pixelSize: 25
                    font.bold: true
                    horizontalAlignment: Text.AlignHCenter
                }

                Text{
                    id: trainingSecText
                    text: {
                        var seconds = training_sec % 60
                        if (seconds.toString().length < 2) {
                            return "0" + seconds
                        }
                        else return seconds
                    }

                    color: "white"
                    width: 40
                    height: icon.height
                    anchors.top: icon.top
                    anchors.topMargin: -15
                    anchors.left: trainingTextSeparator.right
                    font.pixelSize: 25
                    font.bold: true
                    horizontalAlignment: Text.AlignHCenter
                }
            }

            Text{
                id: restMinsText
                text: {
                    var mins = (rest_sec - (rest_sec % 60)) / 60
                    if (mins.toString().length < 2) {
                        return "0" + mins
                    }
                    else return mins
                }

                color: "white"
                width: 40
                height: icon.height
                anchors.top: icon.top
                anchors.topMargin: -15
                anchors.left: icon.left
                anchors.leftMargin: 235
                font.pixelSize: 25
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
            }

            Text{
                id: restTextSeparator
                text: ":"
                color: "white"
                width: 4
                height: icon.height
                anchors.top: icon.top
                anchors.topMargin: -15
                anchors.left: restMinsText.right
                font.pixelSize: 25
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
            }

            Text{
                id: restSecText
                text: {
                    var seconds = rest_sec % 60
                    if (seconds.toString().length < 2) {
                        return "0" + seconds
                    }
                    else return seconds
                }

                color: "white"
                width: 40
                height: icon.height
                anchors.top: icon.top
                anchors.topMargin: -15
                anchors.left: restTextSeparator.right
                font.pixelSize: 25
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
            }

            Text{
                id: lapsText
                text: {
                    var lap = laps
                    if (lap < 10) {
                        if (lap.toString() === "-1") {
                            return "∞"
                        }
                        else return "0" + laps
                    }
                    else return laps
                }
                color: "white"
                width: 40
                height: icon.height
                anchors.top: icon.top
                anchors.topMargin: -15
                anchors.left: parent.left
                anchors.leftMargin:365
                font.pixelSize: 25
                font.bold: true
                horizontalAlignment: Text.AlignHCenter
            }

            // Animate adding and removing of items:

            ListView.onAdd: SequentialAnimation {
                PropertyAction { target: delegateItem; property: "height"; value: 0 }
                NumberAnimation { target: delegateItem; property: "height"; to: 55; duration: 250; easing.type: Easing.InOutQuad }
                //PropertyAction { target: listView; property: "currentIndex"; value: -1 }
            }

            ListView.onRemove: SequentialAnimation {
                id: removeAnimation
                PropertyAction { target: delegateItem; property: "ListView.delayRemove"; value: true }
                NumberAnimation { target: delegateItem; property: "height"; to: 0; duration: 250; easing.type: Easing.InOutQuad }

                // Make sure delayRemove is set back to false so that the item can be destroyed
                PropertyAction { target: delegateItem; property: "ListView.delayRemove"; value: false }
            }
        }
    }

    property bool empty: false

    // The view:
    ListView {
        id: listView

        anchors.fill: parent; //anchors.margins: 20
        model: trainingModel
        delegate: listDelegate
        highlight: Rectangle{color: "#89d7ff"; opacity: 0.5; radius: 5}
        spacing: 1

        ScrollBar{
            flickable: listView
            vertical: true;
        }

    }
}

