// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.0

Rectangle {
    id: rectStart
    anchors.fill: parent
    visible: false

    property int rest_sec: 0
    property int training_sec: 0
    property int laps: 0
    property int currentLap: 1
    property bool run: false

    FontLoader{
        id: fLoader
        source: "qrc:/font/DS-DIGIB.TTF"
    }

    onRunChanged: {
        if (run) mainTimer.start()
        else mainTimer.stop()
    }

    Timer{
        id: mainTimer
        interval: 1000
        onTriggered: {
            training_sec -= 1
            if (training_sec == 0) {
                mainTimer.stop()
                switchRest()
            }
        }
        triggeredOnStart: false
        repeat: true
    }

    Image {
        id: mainBackgroud
        source: "qrc:/images/background_green.png"
        anchors.top:parent.top
        anchors.left: parent.left
        anchors.topMargin: 35
    }

    Image {
        id: timerBackgroud
        source: "qrc:/images/timer_start_background.png"
        anchors.left: parent.left
        anchors.top: parent.top
        anchors.leftMargin: (parent.width - timerBackgroud.width)/2
        anchors.topMargin: 175
        Text {
            id: timerCountMins1
            text: {
                var mins = (training_sec - (training_sec % 60)) / 60
                //console.log(mins.toString().substring(0,1) + " substr")
                if (mins.toString().length < 2) {
                    return "0"
                }
                else return mins.toString().substring(0,1)

            }
            //font.family: digitalFontBold.name
            font.family: fLoader.name
            color: "#ccff00"
            font.bold: true
            font.pixelSize: 160
            horizontalAlignment: Text.AlignRight
            anchors.right: timerCountMins2.left
            anchors.top: parent.top
            //anchors.rightMargin: 5
            anchors.topMargin: 5
            width: 70
            height: 150
        }
        Text {
            id: timerCountMins2
            text: {
                var mins = (training_sec - (training_sec % 60)) / 60
                //console.log(mins.toString().substring(0,1) + " substr")
                if (mins.toString().length < 2) {
                    return mins
                }
                else return mins.toString().substring(1,2)

            }
            //font.family: digitalFontBold.name
            font.family: fLoader.name
            color: "#ccff00"
            font.bold: true
            font.pixelSize: 160
            horizontalAlignment: Text.AlignRight
            anchors.right: timerCountSeparator.left
            anchors.rightMargin: -10
            anchors.top: parent.top
            //anchors.rightMargin: 0
            anchors.topMargin: 5
            width: 70
            height: 100
        }

        Text {
            id: timerCountSeparator
            text: ":"
            //font.family: digitalFontBold.name
            font.family: fLoader.name
            color: "#ccff00"
            font.bold: true
            font.pixelSize: 160
            anchors.top: parent.top
            horizontalAlignment: Text.AlignRight
            anchors.right: timerCountSeconds1.left
            //anchors.rightMargin: 2
            anchors.topMargin: 5
            height: 160
            width: 35
        }

        Text {
            id: timerCountSeconds1
            text: {
                var seconds = training_sec % 60
                if (seconds.toString().length < 2) {
                    return "0"
                }
                else return seconds.toString().substring(0,1)
            }
            //font.family: digitalFontBold.name
            font.family: fLoader.name
            color: "#ccff00"
            font.bold: true
            font.pixelSize: 160
            horizontalAlignment: Text.AlignRight
            anchors.right: timerCountSeconds2.left
            anchors.top: parent.top
            //anchors.rightMargin: 70
            anchors.topMargin: 5
            height: 160
            width: 70
        }

        Text {
            id: timerCountSeconds2
            text: {
                var seconds = training_sec % 60
                if (seconds.toString().length < 2) {
                    return seconds
                }
                else return seconds.toString().substring(1,2)
            }
           // font.family: digitalFontBold.name
            font.family: fLoader.name
            color: "#ccff00"
            font.bold: true
            font.pixelSize: 160
            horizontalAlignment: Text.AlignRight
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.rightMargin: 75
            anchors.topMargin: 5
            height: 160
            width: 70
        }

        /*Text{
            id: textDebug
            font.pixelSize: 70
            color: "yellow"
            anchors.centerIn: parent
            text: soundStart.status
        }
        Text{
            id: textDebug2
            font.pixelSize: 70
            color: "yellow"
            anchors.top: textDebug.bottom
            anchors.left: textDebug.left
            text: soundStart.volume
        }*/

        Text {
            id: timerLapsCount
            text: {
                if (currentLap < 10) return "0" + currentLap
                else return currentLap
            }
            //font.family: digitalFont.name
            font.family: fLoader.name
            color: "#ccff00"
            font.pixelSize: 67
            anchors.top: parent.top
            anchors.left: timerCountSeconds2.right
            anchors.leftMargin: 5
            anchors.topMargin: 20
            //horizontalAlignment: Text.AlignHCenter
        }

        Text {
            id: timerLap
            text: lapString
            font.pixelSize: lapPixel
            color: "#ccff00"
            font.letterSpacing: 2
            anchors.left: timerLapsCount.left
            anchors.top: timerLapsCount.bottom
            //anchors.topMargin: 5
        }
    }

    Image {
        id: cinkaIcon
        source: "qrc:/images/cinka_icon.png"
        anchors.right: trainingText.left
        anchors.top: parent.top
        anchors.rightMargin: 10
        anchors.topMargin: 135
    }

    Text {
        id: trainingText
        text: trainingString.toUpperCase()
        font.pixelSize: 25
        font.letterSpacing: 6
        color: "#003300"
        font.bold: true
        anchors.left: timerBackgroud.left
        anchors.top: parent.top
        anchors.leftMargin: (timerBackgroud.width - trainingText.width)/2
        anchors.topMargin: 135
    }

    Image{
        id: buttonRestart
        source: "qrc:/images/button.png"
        anchors.left: parent.left
        anchors.leftMargin: (parent.width - buttonRestart.width) / 2
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 35
        MouseArea{
            id: mouseRestart
            anchors.fill: parent
            onPressed: parent.opacity = 0.7
            onReleased: parent.opacity = 1
            onClicked: {
                if (vibration) shortFeedback.start()
                //soundStart.play()
                pauseIcon.visible = true
                resumeIcon.visible = false
                //soundStart.play()
                stopTraining()
                if (vibration) longFeedback.stop()
                soundStart.stop()
                //restartTimer()
                console.log("restart clicked")
            }
        }
        Text{
            id: textRestart
            text: backString
            anchors.centerIn: parent
            font.pixelSize: 25
            font.bold: true
            font.family: "Arial"
            color: "black"
        }
    }

    /*Image{
        id: buttonExit
        source: "qrc:/images/button.png"
        anchors.left: parent.left
        anchors.leftMargin: 190
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 35
        MouseArea{
            id: mouseExit
            anchors.fill: parent
            onPressed: parent.opacity = 0.7
            onReleased: parent.opacity = 1
            onClicked: {
                if (vibration) shortFeedback.start()
                soundStart.stop()
                if (vibration) longFeedback.stop()
                stopTraining()
            }
        }
        Text{
            id: textExit
            text: exitString
            anchors.centerIn: parent
            font.pixelSize: 20
            font.bold: true
            font.family: "Arial"
            color: "black"
        }
    }*/

    Image {
        id: pauseIcon
        source: "qrc:/images/pause_icon.png"
        anchors.top: parent.top
        anchors.topMargin: 360
        anchors.left: parent.left
        anchors.leftMargin: (parent.width - pauseIcon.width)/2
        MouseArea{
            id: mousePause
            onPressed: parent.opacity = 0.7
            onReleased: parent.opacity = 1
            anchors.fill: parent
            onClicked: {
                if (vibration) shortFeedback.start()
                pauseIcon.visible = false
                resumeIcon.visible = true
                pauseTimer()
            }
        }
    }

    Image {
        id: resumeIcon
        source: "qrc:/images/resume_icon.png"
        anchors.top: parent.top
        anchors.topMargin: 360
        anchors.left: parent.left
        anchors.leftMargin: (parent.width - resumeIcon.width)/2
        visible: false
        MouseArea{
            id: mouseResume
            onPressed: parent.opacity = 0.7
            onReleased: parent.opacity = 1
            anchors.fill: parent
            onClicked: {
                if (vibration) longFeedback.start()
                soundStart.play()
                pauseIcon.visible = true
                resumeIcon.visible = false
                resumeTimer()
            }
        }
    }

}
