import QtQuick 1.1
import com.nokia.meego 1.0
import QtMobility.feedback 1.1
import QtMultimediaKit 1.1
//import com.nokia.symbian 1.1

PageStackWindow {
    id: mainPage
    anchors.fill: parent

    initialPage: splashScreen

    signal openFile(string title, string sounds);

    property string trainingString: "Training"
    property string lapsString: "Laps"
    property string lapString: "LAP"
    property string setupString: "Setup"
    property string exitString: "Exit"
    property string restartString: "Restart"
    property string backString: "Back"
    property string optionsString: "Options"
    property string addTrainingString: "Add training"
    property string restString: "Pause"
    property string pauseString: "Pause"
    property string saveString: "Save"
    property string removeString: "Remove"
    property string languageString: "Language"
    property string volumeString: "Volume"
    property string yesString: "Yes"
    property string noString: "No"
    property string vibrateString: "Vibration"
    property string soundsString: "Sounds"
    property string chooseString: "Choose..."
    property string defaultString: "Default"
    property string titleString: "Select file"
    property string aboutString: "About"
    property int actualIndex: 0
    property int editIndex: 0

    property bool loaded: false
    property bool splashOff: false

    property string soundFileName: ""
    //property string soundPath: "alarm0.mp3"
    property string soundPath: "qrc:/sound/alarm0.mp3"
    property int soundVolume: 5

    property string training_list: ""

    property string language: "English"

    property int lapsCount: 1
    property int lapsToGo: 1

    property int secondsToGo: 1

    property int timerMin1: 0
    property int timerMin2: 3

    property int timerSecond1: 5
    property int timerSecond2: 2

    property bool vibration: false

    property bool trainingRemoved: false

    property int lapPixel: 40

    signal getTrainings();
    signal getSettings();
    signal saveTrainings(variant trainings);
    signal saveSettings(variant language, variant volume, variant vibration, variant filename, variant path)

    function setLanguage(){
        var lang = language

        if (lang === "English")
        {
            trainingString = "Training"
            lapsString= "Laps"
            lapString= "LAP"
            setupString= "Setup"
            exitString= "Exit"
            restartString= "Restart"
            backString= "Back"
            optionsString= "Options"
            addTrainingString= "Add training"
            restString= "Pause"
            pauseString= "Pause"
            saveString= "Save"
            removeString= "Remove"
            languageString= "Language"
            volumeString= "Volume"
            yesString= "Yes"
            noString= "No"
            vibrateString= "Vibration"
            soundsString= "Sounds"
            chooseString= "Choose..."
            defaultString= "Default"
            titleString= "Select file"
            lapPixel = 30
        }
        else if (lang === "Deutsch")
        {
            trainingString = "Training"
            lapsString= "Runde"
            lapString= "RUND"
            setupString= "Setup"
            exitString= "Exit"
            restartString= "Restart"
            backString= "Zurück"
            optionsString= "Optionen"
            addTrainingString= "Neu"
            restString= "Pause"
            pauseString= "Pause"
            saveString= "Speichern"
            removeString= "Löschen"
            languageString= "Sprache"
            volumeString= "Volumen"
            yesString= "Ja"
            noString= "Nein"
            vibrateString= "Vibration"
            soundsString= "Ton"
            chooseString= "Wählen..."
            defaultString= "Default"
            titleString= "Wählen Sie File"
            lapPixel = 20
        }
        else if (lang === "Slovenčina")
        {
            trainingString = "Tréning"
            lapsString= "Kolá"
            lapString= "KOLO"
            setupString= "Nastavenia"
            exitString= "Ukonči"
            restartString= "Reštart"
            backString= "Späť"
            optionsString= "Možnosti"
            addTrainingString= "Pridať"
            restString= "Pauza"
            pauseString= "Pause"
            saveString= "Ulož"
            removeString= "Vymaž"
            languageString= "Jazyk"
            volumeString= "Hlasitosť"
            yesString= "Áno"
            noString= "Nie"
            vibrateString= "Vibrácie"
            soundsString= "Zvuk"
            chooseString= "Vyber..."
            defaultString= "Predvolený"
            titleString= "Vyber súbor"
            lapPixel = 20
        }
        else if (lang === "Magyar")
        {
            trainingString = "Edzés"
            lapsString= "Körök"
            lapString= "KÖR"
            setupString= "Beállítás"
            exitString= "Kilépés"
            restartString= "Újraindít"
            backString= "Vissza"
            optionsString= "Beállítás"
            addTrainingString= "Új edzés"
            restString= "Szünet"
            pauseString= "Pause"
            saveString= "Mentés"
            removeString= "Törlés"
            languageString= "Nyelv"
            volumeString= "Hangerő"
            yesString= "Igen"
            noString= "Nem"
            vibrateString= "Rezgés"
            soundsString= "Hang"
            chooseString= "Kiválaszt..."
            defaultString= "Alaphang"
            titleString= "Fájl választása"
            lapPixel = 26
        }

    }

    function onSetFileName(filename){
        if (filename === "") return
        soundPath = "file:///" + filename
        var tmparray = filename.split("/")
        soundFileName = tmparray[tmparray.length-1]
        console.log("sound set: " + filename + " + filename: " + soundFileName)
        onSaveSettings()
        soundStart.stop()
        soundStart.source = soundPath
        soundStart.autoLoad = soundPath
    }

    onSoundVolumeChanged: {
        if (soundVolume < 1) {
        soundStart.muted = true
        soundStart.stop()
        soundStart.source = soundPath
        soundStart.autoLoad = soundPath
        }
        else soundStart.muted = false
    }

    function onLoadTrainings(trainings)
    {
        console.log("trainings loaded" + trainings)
        training_list = trainings
        if (training_list.length < 3) training_list = "180;60;10"
        titleMain.refreshList(false)
        loaded = true
    }

    function setTimer(training, rest, laps){
        titleMain.mainLaps = laps
        titleMain.mainRest_sec = rest
        titleMain.mainTraining_sec = training
    }

    function startTimer(training_sec,rest_sec,laps){
        titleMain.visible = false
        trainingStart.visible = true
        trainingStart.training_sec = training_sec
        trainingStart.rest_sec = rest_sec
        trainingStart.laps = laps
        trainingStart.run = true
    }

    function startTimerRest(rest_sec){
        trainingRest.rest_sec = rest_sec
        trainingRest.currentLap = trainingStart.currentLap
    }

    function showSetup(){
        titleMain.visible = false
        setupScreen.visible = true
    }

    function showMain(){
        titleMain.visible = true
        setupScreen.visible = false
        trainingStart.visible = false
        trainingRest.visible = false
        selectTrainingMain.visible = false
    }

    function showSelectTraining(){
        titleMain.visible = false
        if (training_list.length < 3)
        {
            setupScreen.state = "trainings"
            setupScreen.visible = true
        }
        else selectTrainingMain.visible = true
    }

    function stopTraining()
    {
        showMain()
        trainingStart.run = false
        trainingRest.run = false
    }

    function pauseTimer(){
        titleMain.visible = false
        trainingStart.visible = true
        trainingStart.run = false
    }

    function restartTimer(){
        trainingStart.currentLap = 1
        trainingRest.run = false
        trainingRest.visible = false
        trainingStart.visible = true
        startTimer(titleMain.mainTraining_sec,titleMain.mainRest_sec,titleMain.mainLaps)
    }

    function resumeTimer(){
        trainingStart.run = true
    }

    function resumeTraining(){
        if (vibration) longFeedback.start()
        soundStart.play()
        trainingStart.currentLap += 1
        trainingStart.visible = true
        trainingRest.visible = false
        trainingRest.run = false
        trainingStart.run = true
        startTimer(titleMain.mainTraining_sec,titleMain.mainRest_sec,titleMain.mainLaps)

    }

    function switchRest(){
        if (vibration) longFeedback.start()
        soundStart.stop()
        soundStart.play()
        if (trainingStart.currentLap >= trainingStart.laps && trainingStart.laps !== -1) {
            stopTraining()
            return
        }
        startTimerRest(trainingStart.rest_sec)
        trainingStart.run = false
        trainingStart.visible = false
        trainingRest.visible = true
        trainingRest.run = true
    }

    function onSaveSettings(){
        saveSettings(language,soundVolume,vibration,soundFileName,soundPath)
    }

    function onLoadSettings(lang,volume,vibrate,filename,path)
    {
        language = lang
        soundVolume = volume
        vibration = vibrate
        //console.log("Vibration: "+ vibrate)
        //vibration = false
        soundFileName = filename
        soundPath = path

        if (lang === "")
        {
            language = "English"
            soundVolume = 5
            vibration = true
            soundFileName = ""
            soundPath = "alarm0.mp3"
        }

        setLanguage()
        console.log("loaded file: " + path)
    }

    function onGetMusicList(filename, path){
        openFileDialog.addMusicFile(filename, path)
    }

    onLoadedChanged: {
        if (splashOff) {
            titleMain.visible = true
            splashScreen.visible = false
        }
    }

    HapticsEffect {
        id: shortFeedback
        attackIntensity: 0.0
        attackTime: 10
        intensity: 0.6
        duration: 80
        fadeTime: 10
        fadeIntensity: 0.0
    }

    HapticsEffect {
        id: longFeedback
        attackIntensity: 0.0
        attackTime: 300
        intensity: 1
        duration: 1500
        fadeTime: 300
        fadeIntensity: 0.0
    }

    Audio{
        id: soundStart
        onStatusChanged: {
            if (status == 7) {
                source = ""
                source = soundPath
            }
        }
        autoLoad: soundPath
        /*onSourceChanged: {
            if (source == "") return
            volume = 0
            soundStart.play()
            soundStart.stop()
            volume = soundVolume
        }*/

        source: soundPath
        volume: soundVolume/10
        onVolumeChanged: {
            if (Math.round(soundVolume/10,1) != Math.round(volume,1))
                soundVolume = Math.round(volume*10)
        }

        //loops: 1
        muted: soundVolume < 1 ? true : false

        onPlayingChanged: {
            if (soundStart.playing) stopSoundTimer.start()
            else if(!soundStart.playing) {
                source = ""
                source = soundPath
                stopSoundTimer.stop()
            }

            //console.log("play " + soundStart.source)
        }
    }

    Timer{
        id: stopSoundTimer
        interval: 3000
        triggeredOnStart: false
        onTriggered: if (soundStart.playing) soundStart.stop()
        repeat: false
    }

    function refreshList(mainlist){
        titleMain.refreshList(mainlist)
    }

    Title{
        id: titleMain
        orientationLock: PageOrientation.LockPortrait
    }

    TrainingStart
    {
        id: trainingStart

    }

    /*Image {
        id: splashBackgroundImage
        source: "qrc:/images/splash_screen.png"
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.topMargin: 35
    }*/

    TrainingRest
    {
        id: trainingRest
    }

    SetupScreen
    {
        id: setupScreen
    }

    SelectTraining{
        id: selectTrainingMain
    }

    SplashScreen
    {
        id: splashScreen
        orientationLock: PageOrientation.LockPortrait
    }

    OpenFileDialog{
        id: openFileDialog
    }
}

